# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='auth.proto',
  package='org.couchers.auth',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nauth.proto\x12\x11org.couchers.auth\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x1a\n\tSignupReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\x91\x01\n\tSignupRes\x12:\n\tnext_step\x18\x01 \x01(\x0e\x32\'.org.couchers.auth.SignupRes.SignupStep\"H\n\nSignupStep\x12\x15\n\x11SENT_SIGNUP_EMAIL\x10\x00\x12\x10\n\x0c\x45MAIL_EXISTS\x10\x01\x12\x11\n\rINVALID_EMAIL\x10\x02\"$\n\x10UsernameValidReq\x12\x10\n\x08username\x18\x01 \x01(\t\"!\n\x10UsernameValidRes\x12\r\n\x05valid\x18\x01 \x01(\x08\"0\n\x12SignupTokenInfoReq\x12\x1a\n\x0csignup_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"#\n\x12SignupTokenInfoRes\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\xfc\x01\n\x11\x43ompleteSignupReq\x12\x1a\n\x0csignup_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tbirthdate\x18\x05 \x01(\t\x12\x0e\n\x06gender\x18\x06 \x01(\t\x12<\n\x0ehosting_status\x18\x07 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12\x0c\n\x04\x63ity\x18\x08 \x01(\t\x12\x0b\n\x03lat\x18\t \x01(\x01\x12\x0b\n\x03lng\x18\n \x01(\x01\x12\x0e\n\x06radius\x18\x0b \x01(\x01\x12\x12\n\naccept_tos\x18\x0c \x01(\x08\"\x18\n\x08LoginReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x8c\x01\n\x08LoginRes\x12\x38\n\tnext_step\x18\x01 \x01(\x0e\x32%.org.couchers.auth.LoginRes.LoginStep\"F\n\tLoginStep\x12\x11\n\rNEED_PASSWORD\x10\x00\x12\x14\n\x10SENT_LOGIN_EMAIL\x10\x01\x12\x10\n\x0cINVALID_USER\x10\x02\"2\n\x15\x43ompleteTokenLoginReq\x12\x19\n\x0blogin_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"H\n\x07\x41uthReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x17\n\x0fremember_device\x18\x03 \x01(\x08\"*\n\x07\x41uthRes\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0e\n\x06jailed\x18\x02 \x01(\x08\" \n\x10ResetPasswordReq\x12\x0c\n\x04user\x18\x01 \x01(\t\">\n\x18\x43ompletePasswordResetReq\x12\"\n\x14password_reset_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"9\n\x15\x43onfirmChangeEmailReq\x12 \n\x12\x63hange_email_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"Q\n\x15\x43onfirmChangeEmailRes\x12\x38\n\x05state\x18\x01 \x01(\x0e\x32).org.couchers.auth.EmailConfirmationState*\xea\x01\n\x16\x45mailConfirmationState\x12$\n EMAIL_CONFIRMATION_STATE_UNKNOWN\x10\x00\x12$\n EMAIL_CONFIRMATION_STATE_SUCCESS\x10\x01\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL\x10\x02\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL\x10\x03\x32\xb7\x07\n\x04\x41uth\x12\x46\n\x06Signup\x12\x1c.org.couchers.auth.SignupReq\x1a\x1c.org.couchers.auth.SignupRes\"\x00\x12[\n\rUsernameValid\x12#.org.couchers.auth.UsernameValidReq\x1a#.org.couchers.auth.UsernameValidRes\"\x00\x12\x61\n\x0fSignupTokenInfo\x12%.org.couchers.auth.SignupTokenInfoReq\x1a%.org.couchers.auth.SignupTokenInfoRes\"\x00\x12T\n\x0e\x43ompleteSignup\x12$.org.couchers.auth.CompleteSignupReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12\x43\n\x05Login\x12\x1b.org.couchers.auth.LoginReq\x1a\x1b.org.couchers.auth.LoginRes\"\x00\x12\\\n\x12\x43ompleteTokenLogin\x12(.org.couchers.auth.CompleteTokenLoginReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12H\n\x0c\x41uthenticate\x12\x1a.org.couchers.auth.AuthReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12\x42\n\x0e\x44\x65\x61uthenticate\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\rResetPassword\x12#.org.couchers.auth.ResetPasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12^\n\x15\x43ompletePasswordReset\x12+.org.couchers.auth.CompletePasswordResetReq\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x12\x43onfirmChangeEmail\x12(.org.couchers.auth.ConfirmChangeEmailReq\x1a(.org.couchers.auth.ConfirmChangeEmailRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,api__pb2.DESCRIPTOR,])

_EMAILCONFIRMATIONSTATE = _descriptor.EnumDescriptor(
  name='EmailConfirmationState',
  full_name='org.couchers.auth.EmailConfirmationState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_SUCCESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1263,
  serialized_end=1497,
)
_sym_db.RegisterEnumDescriptor(_EMAILCONFIRMATIONSTATE)

EmailConfirmationState = enum_type_wrapper.EnumTypeWrapper(_EMAILCONFIRMATIONSTATE)
EMAIL_CONFIRMATION_STATE_UNKNOWN = 0
EMAIL_CONFIRMATION_STATE_SUCCESS = 1
EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL = 2
EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL = 3


_SIGNUPRES_SIGNUPSTEP = _descriptor.EnumDescriptor(
  name='SignupStep',
  full_name='org.couchers.auth.SignupRes.SignupStep',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SENT_SIGNUP_EMAIL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_EXISTS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_EMAIL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=194,
  serialized_end=266,
)
_sym_db.RegisterEnumDescriptor(_SIGNUPRES_SIGNUPSTEP)

_LOGINRES_LOGINSTEP = _descriptor.EnumDescriptor(
  name='LoginStep',
  full_name='org.couchers.auth.LoginRes.LoginStep',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEED_PASSWORD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENT_LOGIN_EMAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_USER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=780,
  serialized_end=850,
)
_sym_db.RegisterEnumDescriptor(_LOGINRES_LOGINSTEP)


_SIGNUPREQ = _descriptor.Descriptor(
  name='SignupReq',
  full_name='org.couchers.auth.SignupReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='org.couchers.auth.SignupReq.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=118,
)


_SIGNUPRES = _descriptor.Descriptor(
  name='SignupRes',
  full_name='org.couchers.auth.SignupRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_step', full_name='org.couchers.auth.SignupRes.next_step', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNUPRES_SIGNUPSTEP,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=266,
)


_USERNAMEVALIDREQ = _descriptor.Descriptor(
  name='UsernameValidReq',
  full_name='org.couchers.auth.UsernameValidReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.auth.UsernameValidReq.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=304,
)


_USERNAMEVALIDRES = _descriptor.Descriptor(
  name='UsernameValidRes',
  full_name='org.couchers.auth.UsernameValidRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='org.couchers.auth.UsernameValidRes.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=339,
)


_SIGNUPTOKENINFOREQ = _descriptor.Descriptor(
  name='SignupTokenInfoReq',
  full_name='org.couchers.auth.SignupTokenInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signup_token', full_name='org.couchers.auth.SignupTokenInfoReq.signup_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=389,
)


_SIGNUPTOKENINFORES = _descriptor.Descriptor(
  name='SignupTokenInfoRes',
  full_name='org.couchers.auth.SignupTokenInfoRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='org.couchers.auth.SignupTokenInfoRes.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=426,
)


_COMPLETESIGNUPREQ = _descriptor.Descriptor(
  name='CompleteSignupReq',
  full_name='org.couchers.auth.CompleteSignupReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signup_token', full_name='org.couchers.auth.CompleteSignupReq.signup_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.auth.CompleteSignupReq.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.auth.CompleteSignupReq.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='birthdate', full_name='org.couchers.auth.CompleteSignupReq.birthdate', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.auth.CompleteSignupReq.gender', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosting_status', full_name='org.couchers.auth.CompleteSignupReq.hosting_status', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='org.couchers.auth.CompleteSignupReq.city', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.auth.CompleteSignupReq.lat', index=7,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.auth.CompleteSignupReq.lng', index=8,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='org.couchers.auth.CompleteSignupReq.radius', index=9,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept_tos', full_name='org.couchers.auth.CompleteSignupReq.accept_tos', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=681,
)


_LOGINREQ = _descriptor.Descriptor(
  name='LoginReq',
  full_name='org.couchers.auth.LoginReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.LoginReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=707,
)


_LOGINRES = _descriptor.Descriptor(
  name='LoginRes',
  full_name='org.couchers.auth.LoginRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_step', full_name='org.couchers.auth.LoginRes.next_step', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGINRES_LOGINSTEP,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=850,
)


_COMPLETETOKENLOGINREQ = _descriptor.Descriptor(
  name='CompleteTokenLoginReq',
  full_name='org.couchers.auth.CompleteTokenLoginReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='login_token', full_name='org.couchers.auth.CompleteTokenLoginReq.login_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=902,
)


_AUTHREQ = _descriptor.Descriptor(
  name='AuthReq',
  full_name='org.couchers.auth.AuthReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.AuthReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='org.couchers.auth.AuthReq.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remember_device', full_name='org.couchers.auth.AuthReq.remember_device', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=904,
  serialized_end=976,
)


_AUTHRES = _descriptor.Descriptor(
  name='AuthRes',
  full_name='org.couchers.auth.AuthRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.auth.AuthRes.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jailed', full_name='org.couchers.auth.AuthRes.jailed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=978,
  serialized_end=1020,
)


_RESETPASSWORDREQ = _descriptor.Descriptor(
  name='ResetPasswordReq',
  full_name='org.couchers.auth.ResetPasswordReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.ResetPasswordReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1022,
  serialized_end=1054,
)


_COMPLETEPASSWORDRESETREQ = _descriptor.Descriptor(
  name='CompletePasswordResetReq',
  full_name='org.couchers.auth.CompletePasswordResetReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password_reset_token', full_name='org.couchers.auth.CompletePasswordResetReq.password_reset_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1056,
  serialized_end=1118,
)


_CONFIRMCHANGEEMAILREQ = _descriptor.Descriptor(
  name='ConfirmChangeEmailReq',
  full_name='org.couchers.auth.ConfirmChangeEmailReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_email_token', full_name='org.couchers.auth.ConfirmChangeEmailReq.change_email_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1177,
)


_CONFIRMCHANGEEMAILRES = _descriptor.Descriptor(
  name='ConfirmChangeEmailRes',
  full_name='org.couchers.auth.ConfirmChangeEmailRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='org.couchers.auth.ConfirmChangeEmailRes.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1260,
)

_SIGNUPRES.fields_by_name['next_step'].enum_type = _SIGNUPRES_SIGNUPSTEP
_SIGNUPRES_SIGNUPSTEP.containing_type = _SIGNUPRES
_COMPLETESIGNUPREQ.fields_by_name['hosting_status'].enum_type = api__pb2._HOSTINGSTATUS
_LOGINRES.fields_by_name['next_step'].enum_type = _LOGINRES_LOGINSTEP
_LOGINRES_LOGINSTEP.containing_type = _LOGINRES
_CONFIRMCHANGEEMAILRES.fields_by_name['state'].enum_type = _EMAILCONFIRMATIONSTATE
DESCRIPTOR.message_types_by_name['SignupReq'] = _SIGNUPREQ
DESCRIPTOR.message_types_by_name['SignupRes'] = _SIGNUPRES
DESCRIPTOR.message_types_by_name['UsernameValidReq'] = _USERNAMEVALIDREQ
DESCRIPTOR.message_types_by_name['UsernameValidRes'] = _USERNAMEVALIDRES
DESCRIPTOR.message_types_by_name['SignupTokenInfoReq'] = _SIGNUPTOKENINFOREQ
DESCRIPTOR.message_types_by_name['SignupTokenInfoRes'] = _SIGNUPTOKENINFORES
DESCRIPTOR.message_types_by_name['CompleteSignupReq'] = _COMPLETESIGNUPREQ
DESCRIPTOR.message_types_by_name['LoginReq'] = _LOGINREQ
DESCRIPTOR.message_types_by_name['LoginRes'] = _LOGINRES
DESCRIPTOR.message_types_by_name['CompleteTokenLoginReq'] = _COMPLETETOKENLOGINREQ
DESCRIPTOR.message_types_by_name['AuthReq'] = _AUTHREQ
DESCRIPTOR.message_types_by_name['AuthRes'] = _AUTHRES
DESCRIPTOR.message_types_by_name['ResetPasswordReq'] = _RESETPASSWORDREQ
DESCRIPTOR.message_types_by_name['CompletePasswordResetReq'] = _COMPLETEPASSWORDRESETREQ
DESCRIPTOR.message_types_by_name['ConfirmChangeEmailReq'] = _CONFIRMCHANGEEMAILREQ
DESCRIPTOR.message_types_by_name['ConfirmChangeEmailRes'] = _CONFIRMCHANGEEMAILRES
DESCRIPTOR.enum_types_by_name['EmailConfirmationState'] = _EMAILCONFIRMATIONSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignupReq = _reflection.GeneratedProtocolMessageType('SignupReq', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupReq)
  })
_sym_db.RegisterMessage(SignupReq)

SignupRes = _reflection.GeneratedProtocolMessageType('SignupRes', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupRes)
  })
_sym_db.RegisterMessage(SignupRes)

UsernameValidReq = _reflection.GeneratedProtocolMessageType('UsernameValidReq', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEVALIDREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.UsernameValidReq)
  })
_sym_db.RegisterMessage(UsernameValidReq)

UsernameValidRes = _reflection.GeneratedProtocolMessageType('UsernameValidRes', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEVALIDRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.UsernameValidRes)
  })
_sym_db.RegisterMessage(UsernameValidRes)

SignupTokenInfoReq = _reflection.GeneratedProtocolMessageType('SignupTokenInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPTOKENINFOREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupTokenInfoReq)
  })
_sym_db.RegisterMessage(SignupTokenInfoReq)

SignupTokenInfoRes = _reflection.GeneratedProtocolMessageType('SignupTokenInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPTOKENINFORES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupTokenInfoRes)
  })
_sym_db.RegisterMessage(SignupTokenInfoRes)

CompleteSignupReq = _reflection.GeneratedProtocolMessageType('CompleteSignupReq', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETESIGNUPREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.CompleteSignupReq)
  })
_sym_db.RegisterMessage(CompleteSignupReq)

LoginReq = _reflection.GeneratedProtocolMessageType('LoginReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.LoginReq)
  })
_sym_db.RegisterMessage(LoginReq)

LoginRes = _reflection.GeneratedProtocolMessageType('LoginRes', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.LoginRes)
  })
_sym_db.RegisterMessage(LoginRes)

CompleteTokenLoginReq = _reflection.GeneratedProtocolMessageType('CompleteTokenLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETETOKENLOGINREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.CompleteTokenLoginReq)
  })
_sym_db.RegisterMessage(CompleteTokenLoginReq)

AuthReq = _reflection.GeneratedProtocolMessageType('AuthReq', (_message.Message,), {
  'DESCRIPTOR' : _AUTHREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.AuthReq)
  })
_sym_db.RegisterMessage(AuthReq)

AuthRes = _reflection.GeneratedProtocolMessageType('AuthRes', (_message.Message,), {
  'DESCRIPTOR' : _AUTHRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.AuthRes)
  })
_sym_db.RegisterMessage(AuthRes)

ResetPasswordReq = _reflection.GeneratedProtocolMessageType('ResetPasswordReq', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ResetPasswordReq)
  })
_sym_db.RegisterMessage(ResetPasswordReq)

CompletePasswordResetReq = _reflection.GeneratedProtocolMessageType('CompletePasswordResetReq', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEPASSWORDRESETREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.CompletePasswordResetReq)
  })
_sym_db.RegisterMessage(CompletePasswordResetReq)

ConfirmChangeEmailReq = _reflection.GeneratedProtocolMessageType('ConfirmChangeEmailReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMCHANGEEMAILREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ConfirmChangeEmailReq)
  })
_sym_db.RegisterMessage(ConfirmChangeEmailReq)

ConfirmChangeEmailRes = _reflection.GeneratedProtocolMessageType('ConfirmChangeEmailRes', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMCHANGEEMAILRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ConfirmChangeEmailRes)
  })
_sym_db.RegisterMessage(ConfirmChangeEmailRes)


_SIGNUPTOKENINFOREQ.fields_by_name['signup_token']._options = None
_COMPLETESIGNUPREQ.fields_by_name['signup_token']._options = None
_COMPLETETOKENLOGINREQ.fields_by_name['login_token']._options = None
_AUTHREQ.fields_by_name['password']._options = None
_COMPLETEPASSWORDRESETREQ.fields_by_name['password_reset_token']._options = None
_CONFIRMCHANGEEMAILREQ.fields_by_name['change_email_token']._options = None

_AUTH = _descriptor.ServiceDescriptor(
  name='Auth',
  full_name='org.couchers.auth.Auth',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\001',
  create_key=_descriptor._internal_create_key,
  serialized_start=1500,
  serialized_end=2451,
  methods=[
  _descriptor.MethodDescriptor(
    name='Signup',
    full_name='org.couchers.auth.Auth.Signup',
    index=0,
    containing_service=None,
    input_type=_SIGNUPREQ,
    output_type=_SIGNUPRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UsernameValid',
    full_name='org.couchers.auth.Auth.UsernameValid',
    index=1,
    containing_service=None,
    input_type=_USERNAMEVALIDREQ,
    output_type=_USERNAMEVALIDRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SignupTokenInfo',
    full_name='org.couchers.auth.Auth.SignupTokenInfo',
    index=2,
    containing_service=None,
    input_type=_SIGNUPTOKENINFOREQ,
    output_type=_SIGNUPTOKENINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteSignup',
    full_name='org.couchers.auth.Auth.CompleteSignup',
    index=3,
    containing_service=None,
    input_type=_COMPLETESIGNUPREQ,
    output_type=_AUTHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='org.couchers.auth.Auth.Login',
    index=4,
    containing_service=None,
    input_type=_LOGINREQ,
    output_type=_LOGINRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteTokenLogin',
    full_name='org.couchers.auth.Auth.CompleteTokenLogin',
    index=5,
    containing_service=None,
    input_type=_COMPLETETOKENLOGINREQ,
    output_type=_AUTHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Authenticate',
    full_name='org.couchers.auth.Auth.Authenticate',
    index=6,
    containing_service=None,
    input_type=_AUTHREQ,
    output_type=_AUTHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Deauthenticate',
    full_name='org.couchers.auth.Auth.Deauthenticate',
    index=7,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetPassword',
    full_name='org.couchers.auth.Auth.ResetPassword',
    index=8,
    containing_service=None,
    input_type=_RESETPASSWORDREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompletePasswordReset',
    full_name='org.couchers.auth.Auth.CompletePasswordReset',
    index=9,
    containing_service=None,
    input_type=_COMPLETEPASSWORDRESETREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfirmChangeEmail',
    full_name='org.couchers.auth.Auth.ConfirmChangeEmail',
    index=10,
    containing_service=None,
    input_type=_CONFIRMCHANGEEMAILREQ,
    output_type=_CONFIRMCHANGEEMAILRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTH)

DESCRIPTOR.services_by_name['Auth'] = _AUTH

# @@protoc_insertion_point(module_scope)



import setuptools

long_description = """
# Couchers.org Python Client

The next-generation couch surfing platform. Free forever. Community‑led. Non‑profit. Modern. Read more about us at [Couchers.org](https://couchers.org).

This is the Couchers.org Python Client, mainly used for administrative purposes and the like.

Usage of the Couchers.org service provided by the Couchers.org Foundation is governed under our [Terms of Service](https://app.couchers.org/terms).
"""

setuptools.setup(
    name="couchers",
    version="0.0.17",
    author="Couchers.org Foundation and Contributors",
    author_email="support@couchers.org",
    description="Couchers.org: The next-generation couch surfing platform. Free forever. Community‑led. Non‑profit. Modern.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://couchers.org",
    project_urls={
        "GitHub": "https://github.com/Couchers-org/couchers",
        "Bug Tracker": "https://github.com/Couchers-org/couchers/issues",
        "Community Forum": "https://community.couchers.org",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.8",
    install_requires=["grpcio", "protobuf"],
)
